@@ -1,49 +1,13 @@
 import logging
 from email.mime.application import MIMEApplication
-import boto3
+
 from botocore.exceptions import ClientError
 from django.conf import settings
-from django.core.mail import EmailMessage
-import zipfile
-import os
+from django.core.mail import EmailMessage, get_connection
 
 logger = logging.getLogger('dict_config_logger')
 
-
-def email_verification(email):
-    """Function to send email verification"""
-    ses = boto3.client('ses')
-    check = check_if_email_verified(email)
-
-    if check:
-        logger.info("Email is sent for Verification")
-
-        response = ses.verify_email_identity(
-            EmailAddress=email
-        )
-
-        logger.info(response)
-
-
-def check_if_email_verified(email):
-    """Function to check if email id from user is verified """
-    list_emails = list_email_verified()
-    if email in list_emails:
-        logger.info("Email is already Verified")
-        return False
-    return True
-
-
-def list_email_verified():
-    """Function to return list of verified emails """
-
-    ses = boto3.client('ses')
-    response = ses.list_identities(
-        IdentityType='EmailAddress',
-        MaxItems=10
-    )
-    logger.info(response['Identities'])
-    return response['Identities']
+email_backend = get_connection(getattr(settings, "LOG_PATH", None))
 
 
 def send_notifications(email, sender, email_configuration):
@@ -64,8 +28,6 @@ def send_notifications(email, sender, email_configuration):
     # The full path to the file that will be attached to the email.
     # LOG_PATH = email_configuration.get('Log_path')
     ATTACHMENT = getattr(settings, "LOG_PATH", None)
-    zipfile.ZipFile('media/Zipped_file.zip', mode='w').write(ATTACHMENT)
-    print("File Created successfully..")
 
     # The HTML body of the email.
     file_name = email_configuration.get('HTML_File')
@@ -76,20 +38,19 @@ def send_notifications(email, sender, email_configuration):
         faq_url=email_configuration.get('FAQ_URL'),
         unsubscribe=email_configuration.get('Unsubscribe_Email_ID'))
     # Define the attachment part and encode it using MIMEApplication.
-    att = MIMEApplication(open('media/Zipped_file.zip', 'rb').read())
-    os.remove('media/Zipped_file.zip')
+    att = MIMEApplication(open(ATTACHMENT, 'rb').read())
 
     # Add a header to tell the email client to treat this part as an
     # attachment, and to give the attachment a name.
     att.add_header('Content-Disposition', 'attachment',
-                   filename="OpenLXP notifications" + ".zip")
+                   filename="OpenLXP notifications ")
 
     for each_recipient in RECIPIENT:
         try:
             # Provide the contents of the email.
 
             mail = EmailMessage(SUBJECT, BODY_HTML, SENDER,
-                                [each_recipient])
+                                [each_recipient], connection=email_backend)
             mail.content_subtype = "html"
             # Add the attachment to the parent container.
             mail.attach(att)
@@ -129,7 +90,7 @@ def send_notifications_with_msg(email, sender, msg, email_configuration):
             # Provide the contents of the email.
 
             mail = EmailMessage(SUBJECT, BODY_HTML, SENDER,
-                                [each_recipient])
+                                [each_recipient], connection=email_backend)
             mail.content_subtype = "html"
             # Add the attachment to the parent container.
             mail.send()
